var visibleSuggestions = {};

//Request query suggestions for a specific keyphrase from Google
//---------------------------------------------------------------------
//Google Suggest can return different results based on cursor position.
//The position can be specified either as a parameter, or by placing 
//the pipe character "|" in the desired position of the keyphrase, 
//e.g. "fuzzy |widgets".
function requestSuggestions(keyphrase, position){
	var params = {	
		q : keyphrase, 
		output: 'toolbar' 
	};	
	 
	if (typeof(position) != 'undefined'){
		params.cp = position;
	} else if ( keyphrase.indexOf('|') != -1 ){
		params.cp = keyphrase.indexOf('|');
	}
	keyphrase.replace('|', '');
	
	jQuery.getJSON(
		'suggest-proxy.php',
		params,
		processSuggestions
	);
}

//Processes the returned suggestions
function processSuggestions(jsonData){
	var table = $('#results tbody');
	
	for (var i = 0; i < jsonData.length; i++){
		outputSuggestion(jsonData[i]);
	}
	
	$("#results").trigger("update").trigger("sorton",[[[0,0]]]);
	
	if ( $('.result-placeholder').is(':visible') ){
		$('.result-placeholder').hide();
	}
}

//Adds the suggestions to the results table, unless they're already there.
function outputSuggestion(kw){
	//Check if the keyword isn't already in the table.
	if ( typeof(visibleSuggestions[kw.suggestion]) != 'undefined' ){
		return;
	}
	
	var keyword = kw.suggestion;
	var resultCnt = kw.num_queries; 
	
	//Add a new row
	var html = '<tr><td>' + keyword + '</td><td>' + resultCnt + '</td>' +
		'<td><a href="javascript:void(0)" class="btn-dig" title="Find related keywords">Dig</a></td></tr>';
		
	var row = $(html).appendTo('#results tbody');
	
	row.animate({backgroundColor : '#b8ff92'}, 10)
		.animate({backgroundColor : '#fafafa'}, 500, null, function(){
			$(this).css('background-color', '');
		});
		
	visibleSuggestions[kw[0]] = 1;
}

//Set up the JSON callback. Google wants to call window.google.ac.h(), so lets give it to them.
window.google = {
	ac : {
		h : processSuggestions
	}
};

jQuery(function($){
	$('#results').tablesorter({
		headers : {
			0 : {},
			1 : {},
			2 : {
				sorter : false
			}
		}
	});
	
	var collapsedInput = $('#collapsed-input');
	var expandedInput = $('#expanded-input');
	
	function parseInputKeywords(text){
		var queries = text.split(/[\n\r,;]+/);
		queries = queries.filter(function(item){
			return $.trim(item).length > 0;	
		});
		
		return queries;
	}
		
	//What happens when the user clicks "Generate Suggestions"
	$('#the-form').submit(function(e){
		e.preventDefault();
		if ( collapsedInput.is(':visible') ){
			var keywords = parseInputKeywords(collapsedInput.val());
		} else {
			var keywords = parseInputKeywords(expandedInput.val());
		}
		
		for ( var i = 0; i < keywords.length; i++ ){
			requestSuggestions(keywords[i]);
		}
		
		collapsedInput.val('');
		expandedInput.val('');
		
		return false;
	});
	
	//Expand/collapse the input box
	$('#btn-expand').click(function(){
		if ( collapsedInput.is(':visible') ){
			var keywords = parseInputKeywords(collapsedInput.val());
			expandedInput.show().val(keywords.join('\n'));
			collapsedInput.hide();
			$(this).text('Collapse textbox');
		} else {
			var keywords = parseInputKeywords(expandedInput.val());
			collapsedInput.show().val(keywords.join(','));
			expandedInput.hide();
			$(this).text('Expand textbox');
		}
	});
	
	//Clear the results table and the cache
	$('#btn-clear').click(function(){
		$('#results tbody').empty();
		$('.result-placeholder').show();
		visibleSuggestions = {};	
	});
	
	//Display the results in an easily copyable form
	$('#btn-as-text').click(function(){
		var text = [];
		
		$('#results tbody tr').each(function(index, element){
			var cells = $(element).children('td');
			text.push($(cells[0]).text() /*+ '\t' + $(cells[1]).text()*/);			
		});
		
		if ( text.length < 1 ){
			alert('Generate some keywords first!');
			return;
		}
		
		text = text.join('\n'); 
				
		$('#modalbox').modal();	
		
		$('#copybox').text(text).focus().select();
	});
	
	//The "Dig" link makes the script generate more suggestions for a specific keyphrase
	$('.btn-dig').live('click', function(){
		//Find the keyword that's on the same row as the Dig link
		var row = $(this).parents('tr');
		var keyword = row.children('td:first').html();
		requestSuggestions(keyword);
		$(this).hide();
	});
});